==> causeway-bom-2.1.0-source-release.zip: causeway-bom-2.1.0/viewers/wicket/viewer/src/main/java/org/apache/causeway/viewer/wicket/viewer/wicketapp/TargetRespondListenerToResetQueryResultCache.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.causeway.viewer.wicket.viewer.wicketapp;

import javax.inject.Inject;
import javax.inject.Provider;

import org.apache.wicket.ajax.AjaxRequestTarget;

import org.apache.causeway.applib.services.queryresultscache.QueryResultsCache;

import lombok.extern.log4j.Log4j2;

@Log4j2
class TargetRespondListenerToResetQueryResultCache implements AjaxRequestTarget.ITargetRespondListener {

    @Inject private Provider<QueryResultsCache> queryResultsCacheProvider;

    @Override
    public void onTargetRespond(final AjaxRequestTarget target) {

        if(log.isDebugEnabled()) {
            log.debug("RESPOND PHASE STARTED: resetting cache");
        }

        queryResultsCacheProvider.get().onTransactionEnded();
    }


}

==> causeway-bom-3.0.0-source-release.zip: causeway-bom-3.0.0/viewers/wicket/viewer/src/main/java/org/apache/causeway/viewer/wicket/viewer/wicketapp/TargetRespondListenerToResetQueryResultCache.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.causeway.viewer.wicket.viewer.wicketapp;

import jakarta.inject.Inject;
import jakarta.inject.Provider;

import org.apache.wicket.ajax.AjaxRequestTarget;

import org.apache.causeway.applib.services.queryresultscache.QueryResultsCache;

import lombok.extern.log4j.Log4j2;

@Log4j2
class TargetRespondListenerToResetQueryResultCache implements AjaxRequestTarget.ITargetRespondListener {

    @Inject private Provider<QueryResultsCache> queryResultsCacheProvider;

    @Override
    public void onTargetRespond(final AjaxRequestTarget target) {

        if(log.isDebugEnabled()) {
            log.debug("RESPOND PHASE STARTED: resetting cache");
        }

        queryResultsCacheProvider.get().onTransactionEnded();
    }


}
